/*******************************************************************************
* Copyright 2007 Seapine Software, Inc. All rights reserved.
*
* IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
* in consideration of your agreement to the following terms, and your use, installation,
* modification or redistribution of this Software constitutes acceptance of these terms.
* If you do not agree with these terms, please do not use, install, modify or redistribute
* this Software.
*
* In consideration of your agreement to abide by the following terms, and subject to these
* terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
* this original Seapine software (the Software), to use, reproduce, modify and redistribute
* the Software, with or without modifications, in source and/or binary forms; provided that
* if you redistribute the Software in its entirety and without modifications, you must retain
* this notice and the following text and disclaimers in all such redistributions of the Software.
* Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
* or promote products derived from the Software without specific prior written permission from
* Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
* implied, are granted by Seapine herein, including but not limited to any patent rights that
* may be infringed by your derivative works or by other works in which the Software may be
* incorporated.
*
* The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
* EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
* OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS.
*
* IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
* DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
* REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
* UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
* IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
******************************************************************************/
using System;
using System.Collections;
using System.Text;

namespace P4JobExport
{
   // Create a hash table of all P4 user accounts, to relate usernames to full names. We'll then 
   // convert the Job username to the full name, which is what TT expects when you import it as
   // the Entered By and/or Found By field.
   class P4User
   {
      private const string c_strKey = "User";
      private const string c_strValue = "FullName";
      protected Hashtable m_hashData = null;

      public P4User(Array p_array) { m_hashData = new Hashtable(); buildNames(p_array); }

      // Fetch name, or return the name sent if a match isn't found.
      public string getName(string p_str) { string str = (string)m_hashData[p_str]; return (str.Length > 0 ? str:p_str); }

      public void buildNames(Array p_array)
      {
         if (p_array == null) { return; }
         try
         {
            string strKey = "";
            for (int i = 0; i < p_array.Length; ++i)
            {
               string[] astr = P4JobExport.splitString((string)p_array.GetValue(i));
               if (astr[0] == c_strKey)
               {
                  // We shouldn't find another key while we're searching for the value. If we do, 
                  // add the key as the value so we don't leave out a user.
                  if (strKey.Length > 0) { m_hashData.Add(strKey, strKey); }
                  strKey = astr[1];
               }
               else if (astr[0] == c_strValue)
               {
                  // We shouldn't find a value if we're still looking for the key. If we do,
                  // add the value as the key so we don't leave out a user.
                  if (strKey.Length == 0) { strKey = astr[1]; }
                  m_hashData.Add(strKey, astr[1]);
                  strKey = "";
               }
            }
         }
         catch (Exception) {}
      }
   }
}
